@@ -17,9 +17,9 @@ require 'spec_helper'
 
 describe 'ceph::profile::fs' do
 
-  shared_examples_for 'ceph profile fs' do
+  shared_examples 'ceph profile fs' do
 
-    it { is_expected.to contain_ceph__fs('fs_name').with(
+    it { should contain_ceph__fs('fs_name').with(
       'metadata_pool' => 'metadata_pool',
       'data_pool' => 'data_pool'
     )}
